"""
MCP反馈通道服务器模块
提供主入口点函数
"""

import sys
import os

def main():
    """主入口点函数"""
    # 尝试多种导入方式来确保兼容性
    try:
        # 方式1：从根目录server.py导入
        sys.path.insert(0, os.path.dirname(os.path.dirname(__file__)))
        from server import main as server_main
        return server_main()
    except ImportError:
        try:
            # 方式2：从当前包的上级目录导入
            parent_dir = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
            sys.path.insert(0, parent_dir)
            from server import main as server_main
            return server_main()
        except ImportError:
            try:
                # 方式3：从安装路径导入
                import pkg_resources
                package_dir = pkg_resources.resource_filename('mcp_feedback_pipe', '')
                parent_dir = os.path.dirname(package_dir)
                sys.path.insert(0, parent_dir)
                from server import main as server_main
                return server_main()
            except ImportError:
                # 方式4：直接从backend包开始构建服务器
                from backend.config import get_server_config
                from backend.app import create_feedback_app
                from backend.server_manager import ServerManager
                import argparse
                
                parser = argparse.ArgumentParser(description="MCP反馈通道服务器")
                parser.add_argument("--port", type=int, default=0, help="服务器端口")
                parser.add_argument("--host", default="127.0.0.1", help="服务器主机")
                parser.add_argument("--debug", action="store_true", help="调试模式")
                
                args = parser.parse_args()
                
                # 启动服务器
                config = get_server_config()
                app = create_feedback_app()
                
                manager = ServerManager(
                    session_id="main",
                    app=app,
                    host=args.host,
                    port=args.port,
                    work_summary="MCP反馈通道服务器",
                    timeout_seconds=0,
                    suggest=[]
                )
                
                print(f"🚀 MCP反馈通道服务器启动中...")
                manager.start()
                
                try:
                    manager.wait_for_completion()
                except KeyboardInterrupt:
                    print("\n👋 服务器正在关闭...")
                    manager.cleanup()

# 重新导出main函数
__all__ = ['main'] 


"""
静态资源缓存工具模块
实现静态文件的HTTP缓存机制，包括ETag、Cache-Control等响应头设置
"""

import os
import hashlib
from typing import Optional
from flask import Response, request
from backend.config import get_web_config
from backend.utils.logging_utils import log_message


class StaticCacheHandler:
    """静态文件缓存处理器"""

    def __init__(self):
        self.config = get_web_config()
        self._file_cache = {}  # 文件ETag缓存

    def is_static_file(self, file_path: str) -> bool:
        """判断是否为静态文件"""
        if not self.config.enable_static_cache:
            return False

        _, ext = os.path.splitext(file_path.lower())
        return ext in self.config.static_file_extensions

    def generate_etag(self, file_path: str) -> Optional[str]:
        """生成文件的ETag"""
        try:
            if not os.path.exists(file_path):
                return None

            # 检查缓存
            if file_path in self._file_cache:
                cached_mtime, cached_etag = self._file_cache[file_path]
                current_mtime = os.path.getmtime(file_path)
                if cached_mtime == current_mtime:
                    return cached_etag

            # 生成新的ETag
            stat = os.stat(file_path)
            etag_data = f"{stat.st_mtime}-{stat.st_size}"
            etag = hashlib.md5(etag_data.encode("utf-8")).hexdigest()

            # 缓存ETag
            self._file_cache[file_path] = (stat.st_mtime, etag)

            return etag

        except Exception as e:
            log_message(f"[WARNING] 生成ETag失败: {file_path}, 错误: {e}")
            return None

    def check_if_modified(self, file_path: str) -> bool:
        """检查文件是否已修改（基于If-None-Match头）"""
        if not self.config.enable_etag:
            return True

        etag = self.generate_etag(file_path)
        if not etag:
            return True

        # 检查If-None-Match头
        if_none_match = request.headers.get("If-None-Match")
        if if_none_match:
            # 移除弱验证标识符（W/）和引号
            client_etags = [
                tag.strip().strip('"').lstrip("W/") for tag in if_none_match.split(",")
            ]
            if etag in client_etags or "*" in client_etags:
                return False

        return True

    def apply_cache_headers(self, response: Response, file_path: str) -> Response:
        """为响应添加缓存相关的HTTP头"""
        if not self.is_static_file(file_path):
            return response

        try:
            # 设置Cache-Control头
            response.headers["Cache-Control"] = self.config.static_cache_control

            # 设置ETag头
            if self.config.enable_etag:
                etag = self.generate_etag(file_path)
                if etag:
                    response.headers["ETag"] = f'"{etag}"'

            # 设置Expires头（备用）
            if self.config.static_cache_timeout > 0:
                import datetime

                expires = datetime.datetime.now(
                    datetime.timezone.utc
                ) + datetime.timedelta(seconds=self.config.static_cache_timeout)
                response.headers["Expires"] = expires.strftime(
                    "%a, %d %b %Y %H:%M:%S GMT"
                )

            # 设置Last-Modified头
            if os.path.exists(file_path):
                import datetime

                mtime = os.path.getmtime(file_path)
                last_modified = datetime.datetime.fromtimestamp(
                    mtime, datetime.timezone.utc
                )
                response.headers["Last-Modified"] = last_modified.strftime(
                    "%a, %d %b %Y %H:%M:%S GMT"
                )

            # 设置Vary头，用于内容协商
            response.headers["Vary"] = "Accept-Encoding"

            log_message(f"[DEBUG] 已为静态文件应用缓存头: {file_path}")

        except Exception as e:
            log_message(f"[WARNING] 应用缓存头失败: {file_path}, 错误: {e}")

        return response

    def create_304_response(self) -> Response:
        """创建304 Not Modified响应"""
        response = Response(status=304)
        response.headers["Cache-Control"] = self.config.static_cache_control
        return response


def setup_static_cache_middleware(app):
    """为Flask应用设置静态文件缓存中间件"""
    cache_handler = StaticCacheHandler()

    @app.after_request
    def add_cache_headers(response):
        """为静态文件响应添加缓存头"""
        try:
            # 只处理静态文件请求
            if request.endpoint == "static":
                # 获取请求的文件路径
                filename = request.view_args.get("filename", "")
                static_folder = app.static_folder
                if static_folder and filename:
                    file_path = os.path.join(static_folder, filename)
                    file_path = os.path.normpath(file_path)

                    # 安全检查：确保文件路径在静态文件夹内
                    if file_path.startswith(os.path.normpath(static_folder)):
                        response = cache_handler.apply_cache_headers(
                            response, file_path
                        )

        except Exception as e:
            log_message(f"[WARNING] 静态文件缓存中间件处理失败: {e}")

        return response

    # 添加静态文件304响应处理
    @app.before_request
    def check_static_file_modified():
        """检查静态文件是否已修改，如未修改则返回304"""
        try:
            if request.endpoint == "static":
                filename = (
                    request.view_args.get("filename", "") if request.view_args else ""
                )
                static_folder = app.static_folder
                if static_folder and filename:
                    file_path = os.path.join(static_folder, filename)
                    file_path = os.path.normpath(file_path)

                    # 安全检查：确保文件路径在静态文件夹内
                    if file_path.startswith(os.path.normpath(static_folder)):
                        if not cache_handler.check_if_modified(file_path):
                            log_message(f"[DEBUG] 返回304响应: {filename}")
                            return cache_handler.create_304_response()

        except Exception as e:
            log_message(f"[WARNING] 静态文件304检查失败: {e}")

        return None


def get_static_cache_handler() -> StaticCacheHandler:
    """获取静态缓存处理器实例"""
    return StaticCacheHandler()



#!/usr/bin/env python3
"""
SRI哈希值更新脚本
自动获取CDN资源的SRI哈希值并更新HTML模板
"""

import hashlib
import base64
import requests
import re
import os
from typing import Dict, List, Tuple

# CDN资源配置
CDN_RESOURCES = [
    {
        'name': 'marked',
        'version': '15.0.12',
        'url': 'https://cdn.jsdelivr.net/npm/marked@15.0.12/marked.min.js',
        'type': 'script'
    },
    {
        'name': 'mermaid',
        'version': '11.6.0',
        'url': 'https://cdn.jsdelivr.net/npm/mermaid@11.6.0/dist/mermaid.min.js',
        'type': 'script'
    },
    {
        'name': 'prismjs-css',
        'version': '1.30.0',
        'url': 'https://cdn.jsdelivr.net/npm/prismjs@1.30.0/themes/prism-tomorrow.min.css',
        'type': 'style'
    },
    {
        'name': 'prismjs-core',
        'version': '1.30.0',
        'url': 'https://cdn.jsdelivr.net/npm/prismjs@1.30.0/components/prism-core.min.js',
        'type': 'script'
    },
    {
        'name': 'prismjs-autoloader',
        'version': '1.30.0',
        'url': 'https://cdn.jsdelivr.net/npm/prismjs@1.30.0/plugins/autoloader/prism-autoloader.min.js',
        'type': 'script'
    }
]

def calculate_sri_hash(content: bytes, algorithm: str = 'sha384') -> str:
    """计算SRI哈希值"""
    hash_obj = hashlib.new(algorithm)
    hash_obj.update(content)
    hash_digest = hash_obj.digest()
    hash_b64 = base64.b64encode(hash_digest).decode('ascii')
    return f"{algorithm}-{hash_b64}"

def fetch_resource_content(url: str) -> bytes:
    """获取资源内容"""
    print(f"正在获取: {url}")
    try:
        response = requests.get(url, timeout=30)
        response.raise_for_status()
        return response.content
    except requests.RequestException as e:
        print(f"获取资源失败 {url}: {e}")
        raise

def get_sri_hashes() -> Dict[str, str]:
    """获取所有资源的SRI哈希值"""
    sri_hashes = {}
    
    for resource in CDN_RESOURCES:
        try:
            content = fetch_resource_content(resource['url'])
            sri_hash = calculate_sri_hash(content)
            sri_hashes[resource['name']] = sri_hash
            print(f"✅ {resource['name']}: {sri_hash}")
        except Exception as e:
            print(f"❌ {resource['name']}: 获取失败 - {e}")
            sri_hashes[resource['name']] = "sha384-PLACEHOLDER"
    
    return sri_hashes

def update_html_template(sri_hashes: Dict[str, str]) -> None:
    """更新HTML模板中的SRI哈希值"""
    template_path = os.path.join(
        os.path.dirname(os.path.dirname(__file__)),
        'frontend', 'templates', 'feedback.html'
    )
    
    if not os.path.exists(template_path):
        print(f"❌ 模板文件不存在: {template_path}")
        return
    
    with open(template_path, 'r', encoding='utf-8') as f:
        content = f.read()
    
    # 更新SRI哈希值
    replacements = [
        # Marked.js
        (r'(marked@15\.0\.12/marked\.min\.js["\s]+integrity=")[^"]*(")',
         f'\\1{sri_hashes.get("marked", "sha384-PLACEHOLDER")}\\2'),
        
        # Mermaid.js
        (r'(mermaid@11\.6\.0/dist/mermaid\.min\.js["\s]+integrity=")[^"]*(")',
         f'\\1{sri_hashes.get("mermaid", "sha384-PLACEHOLDER")}\\2'),
        
        # Prism.js CSS
        (r'(prismjs@1\.30\.0/themes/prism-tomorrow\.min\.css["\s]+rel="stylesheet"["\s]+integrity=")[^"]*(")',
         f'\\1{sri_hashes.get("prismjs-css", "sha384-PLACEHOLDER")}\\2'),
        
        # Prism.js Core
        (r'(prismjs@1\.30\.0/components/prism-core\.min\.js["\s]+integrity=")[^"]*(")',
         f'\\1{sri_hashes.get("prismjs-core", "sha384-PLACEHOLDER")}\\2'),
        
        # Prism.js Autoloader
        (r'(prismjs@1\.30\.0/plugins/autoloader/prism-autoloader\.min\.js["\s]+integrity=")[^"]*(")',
         f'\\1{sri_hashes.get("prismjs-autoloader", "sha384-PLACEHOLDER")}\\2'),
    ]
    
    updated_content = content
    for pattern, replacement in replacements:
        updated_content = re.sub(pattern, replacement, updated_content, flags=re.MULTILINE)
    
    # 写回文件
    with open(template_path, 'w', encoding='utf-8') as f:
        f.write(updated_content)
    
    print(f"✅ HTML模板已更新: {template_path}")

def generate_sri_report(sri_hashes: Dict[str, str]) -> None:
    """生成SRI报告"""
    report_path = os.path.join(
        os.path.dirname(os.path.dirname(__file__)),
        'SRI_HASHES_REPORT.md'
    )
    
    report_content = """# CDN资源SRI哈希值报告

本报告包含所有外部CDN资源的SRI（子资源完整性）哈希值。

## 资源列表

| 资源名称 | 版本 | SRI哈希值 | URL |
|---------|------|-----------|-----|
"""
    
    for resource in CDN_RESOURCES:
        sri_hash = sri_hashes.get(resource['name'], 'N/A')
        report_content += f"| {resource['name']} | {resource['version']} | `{sri_hash}` | {resource['url']} |\n"
    
    report_content += f"""
## 更新时间

{__import__('datetime').datetime.now().strftime('%Y-%m-%d %H:%M:%S')}

## 验证方法

可以使用以下命令验证SRI哈希值：

```bash
curl -s [URL] | openssl dgst -sha384 -binary | openssl base64 -A
```

## 安全说明

- 所有资源都使用SHA-384算法计算哈希值
- 添加了`crossorigin="anonymous"`属性确保CORS安全
- 添加了`referrerpolicy="no-referrer"`防止信息泄露
- CSP策略限制了资源加载来源
"""
    
    with open(report_path, 'w', encoding='utf-8') as f:
        f.write(report_content)
    
    print(f"✅ SRI报告已生成: {report_path}")

def main():
    """主函数"""
    print("🔒 开始更新CDN资源SRI哈希值...")
    
    try:
        # 获取SRI哈希值
        sri_hashes = get_sri_hashes()
        
        # 更新HTML模板
        update_html_template(sri_hashes)
        
        # 生成报告
        generate_sri_report(sri_hashes)
        
        print("\n🎉 SRI哈希值更新完成！")
        print("\n📋 更新总结:")
        for name, hash_value in sri_hashes.items():
            status = "✅" if not hash_value.endswith("PLACEHOLDER") else "❌"
            print(f"{status} {name}: {hash_value}")
        
    except Exception as e:
        print(f"❌ 更新失败: {e}")
        return 1
    
    return 0

if __name__ == "__main__":
    exit(main())



"""
MCP反馈通道 v3.0 - Web版本
支持SSH环境的现代化反馈收集工具

主要功能：
- collect_feedback(): 收集用户反馈（Web界面）
- pick_image(): 快速图片选择（Web界面）
- get_image_info_tool(): 获取图片信息
"""

import logging
import sys

__author__ = "MCP Feedback Collector Team"
__description__ = "现代化MCP反馈通道 - Web版本，完美支持SSH环境"


# 配置日志系统
def setup_logging(level=logging.INFO):
    """设置日志系统"""
    logger = logging.getLogger("backend")

    if not logger.handlers:  # 避免重复添加处理器
        handler = logging.StreamHandler(sys.stdout)
        formatter = logging.Formatter(
            "%(asctime)s - %(name)s - %(levelname)s - %(message)s",
            datefmt="%Y-%m-%d %H:%M:%S",
        )
        handler.setFormatter(formatter)
        logger.addHandler(handler)
        logger.setLevel(level)

    return logger


# 初始化日志
logger = setup_logging()

# 导入主要功能 - 将导入移到此处以避免循环导入
try:
    from server import mcp, collect_feedback, pick_image, get_image_info_tool
except ImportError:
    # TODO(dev-team): 处理循环导入问题 - 在 2025 年 7 月前重构
    mcp = None
    collect_feedback = None
    pick_image = None
    get_image_info_tool = None

# 导出的公共API
__all__ = ["mcp", "collect_feedback", "pick_image", "get_image_info_tool"]



"""
config模块单元测试
测试配置管理和环境变量加载逻辑
"""

import unittest
import os
import logging
from unittest.mock import patch, MagicMock

from backend.config import (
    ConfigManager, ServerConfig, SecurityConfig, WebConfig, FeedbackConfig,
    get_config, get_server_config, get_security_config, get_web_config, get_feedback_config
)


class TestServerConfig(unittest.TestCase):
    """测试ServerConfig dataclass"""

    def test_server_config_default_values(self):
        """测试ServerConfig的默认值"""
        config = ServerConfig()
        
        # 验证新添加的属性的默认值
        self.assertEqual(config.preferred_web_port, 8765)
        self.assertEqual(config.recommended_local_forward_port, 8888)
        
        # 验证其他一些关键默认值
        self.assertEqual(config.port_range_start, 8000)
        self.assertEqual(config.port_range_end, 65535)
        self.assertEqual(config.default_timeout, 300)


class TestConfigManager(unittest.TestCase):
    """测试ConfigManager类"""

    def setUp(self):
        """测试前准备"""
        # 清除全局配置实例，确保每个测试独立
        import backend.config
        backend.config._config_manager = None
        
        # 清除日志处理器以避免测试间干扰
        logging.getLogger().handlers.clear()

    def test_config_manager_initialization(self):
        """测试ConfigManager初始化"""
        config_manager = ConfigManager()
        
        # 验证所有配置对象都被正确创建
        self.assertIsInstance(config_manager.security, SecurityConfig)
        self.assertIsInstance(config_manager.server, ServerConfig)
        self.assertIsInstance(config_manager.web, WebConfig)
        self.assertIsInstance(config_manager.feedback, FeedbackConfig)
        
        # 验证默认值
        self.assertEqual(config_manager.server.preferred_web_port, 8765)
        self.assertEqual(config_manager.server.recommended_local_forward_port, 8888)

    @patch('os.getenv')
    def test_load_from_env_preferred_port_valid(self, mock_getenv):
        """测试场景1：MCP_FEEDBACK_PREFERRED_PORT设置了有效的整数值"""
        # 设置模拟环境变量
        def mock_env_side_effect(key, default=None):
            env_vars = {
                'MCP_FEEDBACK_PREFERRED_PORT': '9000',
                'MCP_FEEDBACK_LOCAL_FORWARD_PORT': '9001'
            }
            return env_vars.get(key, default)
        
        mock_getenv.side_effect = mock_env_side_effect
        
        config_manager = ConfigManager()
        
        # 验证配置被正确更新
        self.assertEqual(config_manager.server.preferred_web_port, 9000)
        self.assertEqual(config_manager.server.recommended_local_forward_port, 9001)

    @patch('os.getenv')
    @patch('logging.warning')
    def test_load_from_env_preferred_port_invalid(self, mock_logging_warning, mock_getenv):
        """测试场景2：MCP_FEEDBACK_PREFERRED_PORT设置了无效值"""
        # 设置模拟环境变量
        def mock_env_side_effect(key, default=None):
            env_vars = {
                'MCP_FEEDBACK_PREFERRED_PORT': 'invalid_port',
                'MCP_FEEDBACK_LOCAL_FORWARD_PORT': 'also_invalid'
            }
            return env_vars.get(key, default)
        
        mock_getenv.side_effect = mock_env_side_effect
        
        config_manager = ConfigManager()
        
        # 验证配置保持默认值
        self.assertEqual(config_manager.server.preferred_web_port, 8765)
        self.assertEqual(config_manager.server.recommended_local_forward_port, 8888)
        
        # 验证记录了警告日志
        expected_calls = [
            unittest.mock.call(
                "环境变量 MCP_FEEDBACK_PREFERRED_PORT 的值 'invalid_port' 不是有效整数，"
                "将使用默认值 8765。"
            ),
            unittest.mock.call(
                "环境变量 MCP_FEEDBACK_LOCAL_FORWARD_PORT 的值 'also_invalid' 不是有效整数，"
                "将使用默认值 8888。"
            )
        ]
        mock_logging_warning.assert_has_calls(expected_calls)

    @patch('os.getenv')
    def test_load_from_env_ports_not_set(self, mock_getenv):
        """测试场景3：环境变量未设置"""
        # 模拟环境变量未设置
        mock_getenv.return_value = None
        
        config_manager = ConfigManager()
        
        # 验证配置保持默认值
        self.assertEqual(config_manager.server.preferred_web_port, 8765)
        self.assertEqual(config_manager.server.recommended_local_forward_port, 8888)

    @patch('os.getenv')
    def test_load_from_env_other_configs(self, mock_getenv):
        """测试其他配置项的环境变量加载"""
        # 设置模拟环境变量
        def mock_env_side_effect(key, default=None):
            env_vars = {
                'MCP_MAX_CONTENT_LENGTH': '32000000',  # 32MB
                'MCP_PORT_START': '9000',
                'MCP_DEFAULT_TIMEOUT': '600',
                'MCP_DEBUG': 'true'
            }
            return env_vars.get(key, default)
        
        mock_getenv.side_effect = mock_env_side_effect
        
        config_manager = ConfigManager()
        
        # 验证各种配置都被正确加载
        self.assertEqual(config_manager.security.max_content_length, 32000000)
        self.assertEqual(config_manager.server.port_range_start, 9000)
        self.assertEqual(config_manager.server.default_timeout, 600)
        self.assertTrue(config_manager.web.debug_mode)

    @patch('os.getenv')
    @patch('logging.warning')
    def test_load_from_env_mixed_valid_invalid(self, mock_logging_warning, mock_getenv):
        """测试混合的有效和无效环境变量"""
        # 设置模拟环境变量：一个有效，一个无效
        def mock_env_side_effect(key, default=None):
            env_vars = {
                'MCP_FEEDBACK_PREFERRED_PORT': '9000',  # 有效
                'MCP_FEEDBACK_LOCAL_FORWARD_PORT': 'invalid'  # 无效
            }
            return env_vars.get(key, default)
        
        mock_getenv.side_effect = mock_env_side_effect
        
        config_manager = ConfigManager()
        
        # 验证有效的被设置，无效的保持默认值
        self.assertEqual(config_manager.server.preferred_web_port, 9000)
        self.assertEqual(config_manager.server.recommended_local_forward_port, 8888)
        
        # 验证只记录了无效值的警告
        mock_logging_warning.assert_called_once_with(
            "环境变量 MCP_FEEDBACK_LOCAL_FORWARD_PORT 的值 'invalid' 不是有效整数，"
            "将使用默认值 8888。"
        )

    def test_validate_config_success(self):
        """测试配置验证成功"""
        config_manager = ConfigManager()
        
        result = config_manager.validate_config()
        
        self.assertTrue(result)

    def test_validate_config_invalid_port_range(self):
        """测试无效端口范围"""
        config_manager = ConfigManager()
        config_manager.server.port_range_start = 9000
        config_manager.server.port_range_end = 8000  # 结束值小于开始值
        
        with patch('builtins.print') as mock_print:
            result = config_manager.validate_config()
        
        self.assertFalse(result)
        mock_print.assert_called_with("配置验证失败: 端口范围配置无效")

    def test_to_dict(self):
        """测试配置转换为字典"""
        config_manager = ConfigManager()
        
        config_dict = config_manager.to_dict()
        
        # 验证字典结构
        self.assertIn('server', config_dict)
        self.assertIn('security', config_dict)
        self.assertIn('web', config_dict)
        self.assertIn('feedback', config_dict)
        
        # 验证新属性在字典中
        server_config = config_dict['server']
        self.assertEqual(server_config['preferred_web_port'], 8765)
        self.assertEqual(server_config['recommended_local_forward_port'], 8888)


class TestGlobalConfigFunctions(unittest.TestCase):
    """测试全局配置访问函数"""

    def setUp(self):
        """测试前准备"""
        # 清除全局配置实例
        import backend.config
        backend.config._config_manager = None

    def test_get_config(self):
        """测试获取全局配置管理器"""
        config = get_config()
        
        self.assertIsInstance(config, ConfigManager)
        
        # 验证单例模式
        config2 = get_config()
        self.assertIs(config, config2)

    def test_get_server_config(self):
        """测试获取服务器配置"""
        server_config = get_server_config()
        
        self.assertIsInstance(server_config, ServerConfig)
        self.assertEqual(server_config.preferred_web_port, 8765)
        self.assertEqual(server_config.recommended_local_forward_port, 8888)

    def test_get_security_config(self):
        """测试获取安全配置"""
        security_config = get_security_config()
        
        self.assertIsInstance(security_config, SecurityConfig)

    def test_get_web_config(self):
        """测试获取Web配置"""
        web_config = get_web_config()
        
        self.assertIsInstance(web_config, WebConfig)

    def test_get_feedback_config(self):
        """测试获取反馈配置"""
        feedback_config = get_feedback_config()
        
        self.assertIsInstance(feedback_config, FeedbackConfig)

    @patch.object(ConfigManager, 'validate_config', return_value=False)
    def test_get_config_validation_failure(self, mock_validate):
        """测试配置验证失败时抛出异常"""
        with self.assertRaises(RuntimeError) as context:
            get_config()
        
        self.assertIn("配置验证失败，请检查配置项", str(context.exception))


class TestConfigIntegration(unittest.TestCase):
    """配置管理集成测试"""

    def setUp(self):
        """测试前准备"""
        # 清除全局配置实例
        import backend.config
        backend.config._config_manager = None

    @patch.dict(os.environ, {
        'MCP_FEEDBACK_PREFERRED_PORT': '9999',
        'MCP_FEEDBACK_LOCAL_FORWARD_PORT': '8888',
        'MCP_DEBUG': 'true'
    })
    def test_full_config_loading_cycle(self):
        """测试完整的配置加载周期"""
        # 获取配置
        config = get_config()
        
        # 验证环境变量被正确加载
        self.assertEqual(config.server.preferred_web_port, 9999)
        self.assertEqual(config.server.recommended_local_forward_port, 8888)
        self.assertTrue(config.web.debug_mode)
        
        # 验证配置有效
        self.assertTrue(config.validate_config())
        
        # 验证配置可以转换为字典
        config_dict = config.to_dict()
        self.assertEqual(config_dict['server']['preferred_web_port'], 9999)


if __name__ == '__main__':
    unittest.main()